@@ -1,68 +1,92 @@
-# PODNAME: Domain::Details
+package Domain::Details;
+
 # ABSTRACT: Domain class with DNS/SSL/WHOIS fields
 
 use v5.36;
 use autouse 'Carp' => qw( carp croak );
+# use autouse 'Data::Dumper' => qw( Dumper );
 use autouse 'Data::Printer' => qw( p );
-use Object::Pad 0.78 ':experimental(init_expr)';
 
-package Domain::Details;
-
-# @formatter:off
-class Domain::Details :strict( params ) :does(Domain::Details::SSL) {
-# @formatter:on
+use Object::Pad ':experimental(init_expr)';
+use Syntax::Keyword::Match;
+use Net::Domain::ExpireDate; # Function: expire_date
+use Domain::PublicSuffix;    # Method: get_root_domain
+use POSIX;                   # Functions: setlocale, LC_ALL
+use Net::SSL::ExpireDate;
+use Net::DNS;
+use Geo::IP;
+use Term::ANSIColor;
 
+class Domain::Details {
   use experimental qw( try );
-  use Syntax::Keyword::Match;
-  use Net::Domain::ExpireDate; # Function: expire_date
-  use Domain::PublicSuffix;    # Method: get_root_domain
-  use POSIX;                   # Functions: setlocale, LC_ALL
-  use Net::DNS;
-  use Geo::IP;
-  use Term::ANSIColor qw( colorstrip );
-  use Clipboard; # Class method: copy_to_all_selections
-
   # @formatter:off
-
   field $domain :param :reader;
-
-
-  field $description :param :accessor = undef;
-
-
-  method whois_expiration ( $format //= '%B %d, %Y' ) {
+  field $comment :accessor;
+  field $expiration :reader { $self -> _expiration };
+  field $ssl_expiration :reader { $self -> _ssl_expiration };
+  # @formatter:on
+  method _expiration ( $format //= '%B %d, %Y' ) {
     my $publicsuffix = Domain::PublicSuffix -> new;
     setlocale( LC_ALL , 'en_US.UTF-8' );
     return expire_date( $publicsuffix -> get_root_domain( $domain ) , $format ); # domain without the www. prefix
   }
+  method _ssl_expiration ( $format //=  "%s %s, %s" ) {
+    my $ssl = Net::SSL::ExpireDate -> new( https => $domain );
+    try {
+      return sprintf $format ,
+        $ssl -> expire_date -> month_name ,
+        $ssl -> expire_date -> day ,
+        $ssl -> expire_date -> year;
+    }
+    catch($message) {
+      return undef;
+    }
+  }
 
-
-  method dns ( ) {
+  # @formatter:off
+  method print_ssl :common ( $domain ) {
   # @formatter:on
-    my $resolver = Net::DNS::Resolver -> new;
-    my $geo = Geo::IP -> open( '/usr/share/GeoIP/GeoIP.dat' );
-    # Set path explicitly because Perlbrew 5.36 on Debian fails to open for searching in /usr/local when Geo::IP is being installed with "cpan"
-    # Installing the Debian package libgeo-ip-perl probably fixes that
+    my $ssl = Net::SSL::ExpireDate -> new( https => $domain );
+    try {
+      my %date = ( # Class: DateTime
+        expire => $ssl -> expire_date ,
+        issue  => $ssl -> begin_date
+      );
+      printf( colored( [ 'red' ] , "SSL Expiry: %s %s, %s\n" ) , $date{expire} -> month_name , $date{expire} -> day , $date{expire} -> year );
+      printf( colored( [ 'green' ] , "SSL Issue: %s %s, %s\n" ) , $date{issue} -> month_name , $date{issue} -> day , $date{issue} -> year );
+      say colored( [ 'bright_red' , 'bold' ] , 'EXPIRES IN 14 DAYS' )
+        if defined $ssl -> is_expired( '14 days' );
+    }
+    catch($message) {
+      warn "SSL: $message";
+    }
+  }
 
-    my ( $cname , $ptr );
+  # @formatter:off
+  method print_dns :common ( $domain ) {
+  # @formatter:on
+    my $dns = Net::DNS::Resolver -> new;
 
-    my $a = $resolver -> query( $domain , 'A' );
+    my $a = $dns -> query( $domain , 'A' ); # may return Net::DNS::RR::CNAME (w/ cname method)
     my @a = $a -> answer if defined $a;
 
-    my $mx = $resolver -> query( $domain , 'MX' );
+    my $cname;
+
+    my $mx = $dns -> query( $domain , 'MX' ); # class: Net::DNS::Packet
     my @mx = $mx -> answer if defined $mx;
 
-    my $ns = $resolver -> query( $domain , 'NS' );
+    my $ns = $dns -> query( $domain , 'NS' );
     my @ns = $ns -> answer if defined $ns;
 
-    my $txt = $resolver -> query( $domain , 'TXT' );
+    my $ptr;
+
+    my $txt = $dns -> query( $domain , 'TXT' );
     my @txt = $txt -> answer if defined $txt;
 
-    my $soa = $resolver -> query( $domain , 'SOA' );
+    my $soa = $dns -> query( $domain , 'SOA' );
     my @soa = $soa -> answer if defined $soa;
 
     my $answer;
-
     my %dns = (
       a     => [] ,
       cname => '' ,
@@ -70,16 +94,22 @@ class Domain::Details :strict( params ) :does(Domain::Details::SSL) {
       mx    => [] ,
       ns    => [] ,
       txt   => [] ,
-    ); # to push individual record values here
+    ); # TODO: %dns_colors
 
-    for my $record ( @a , @mx , @ns , @txt , @soa ) {
+    my $geo = Geo::IP -> open( '/usr/share/GeoIP/GeoIP.dat' );
+    # Debian, perlbrew 5.36 fails to open for searching in /usr/local when Geo::IP is being installed with cpan
+    # libgeo-ip-perl Debian package probably patches it
+    # my $geo = Geo::IP->new(GEOIP_MEMORY_CACHE); # faster
+
+    for my $record ( @a , @mx , @ns , @txt , @soa ) # Net::DNS::RR object list
+    {
       match( $record -> type : eq )
       {
         case( 'A' )
         {
           $answer .= sprintf( "A:\t%s (%s)\n" , $record -> address , $geo -> country_code_by_addr( $record -> address ));
           push( $dns{a} -> @* , $record -> address );
-          $ptr = $resolver -> query( $record -> address , 'PTR' ); # Net::DNS::Packet
+          $ptr = $dns -> query( $record -> address , 'PTR' ); # Net::DNS::Packet
           if ( $ptr ) {
             my @ptr = $ptr -> answer; # [ Net::DNS:RR, ... ]
             $answer .= Term::ANSIColor::colored( [ 'bright_cyan' ] , sprintf( "P:\t%s (%s)\n" , $ptr[0] -> ptrdname , $geo -> country_code_by_name( $ptr[0] -> ptrdname )));
@@ -123,29 +153,13 @@ class Domain::Details :strict( params ) :does(Domain::Details::SSL) {
 
     }
 
+    # say Data::Dumper::Dumper %dns;
+
     $answer = $answer . $cname if defined $cname;
-    return $answer;
+    # return $answer;
+    say $answer;
   }
 
-
-  # @formatter:off
-  method summary () {
-  # @formatter:on
-
-    my $summary = <<~ "SUMMARY";
-    SSL Expiration   : @{[$self -> ssl_expiration]} @{[$self -> ssl_expires_soon ? '(Expires Soon)' : '' ]}
-    SSL Issue        : @{[$self -> ssl_issue]}
-    WHOIS Expiration : @{[$self -> whois_expiration]}
-
-    DNS              :
-
-    @{[$self->dns]}
-    SUMMARY
-    say $summary;
-    Clipboard -> copy_to_all_selections( colorstrip $summary );
-  }
-
-
 }
 
 __END__
@@ -160,35 +174,7 @@ Domain::Details - Domain class with DNS/SSL/WHOIS fields
 
 =head1 VERSION
 
-version 0.230340
-
-=head1 METHODS
-
-=head2 domain
-
-Returns the current domain as created with the C<new> constructor
-
-=head2 description
-
-Returns or sets an optional description (comment) on the domain object
-
-=head2 whois_expiration
-
-Returns domain's expiration date using the L<Net::ExpireDate> module's C<expire_date> function
-
-Derives the root domain using L<Domain::PublicSuffix> class' C<get_root_domain> method
-
-Accepts optional argument to specify the format the date is returned in
-
-=head2 dns
-
-L<Net::DNS> records (A, CNAME, MX, NS, TXT, and SOA) with with L<Geo::IP>
-
-Uses L<Syntax::Keyword::Match> to topicalize C<< $record - >> type>
-
-=head2 summary
-
-Output summary, and copy it into the clipboard stripping colors with L<C<colorstrip>|Term::ANSIColor/colorstrip(STRING[, STRING ...])>
+version 1.230280
 
 =head1 AUTHOR
 
